@@ -5,5 +5,3 @@ import pkg_resources
 pkg_resources.require('WebOb')
 pkg_resources.require('oauth2')
 pkg_resources.require('httplib2') # dependency of oauth2
-# FIXME pumazi: wsgiref is a temporary dependency and should be factored out.
-pkg_resources.require('wsgiref')
