@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 import unittest
 import urllib
-import urlparse
 import xmlrpclib
+import urlparse
 
 from webob import Request, Response
 
@@ -15,24 +15,28 @@ class ProviderTestBase(unittest.TestCase):
         return storage
 
     def _make_data(self, cls, assignable):
+        """Creates dummy token *like* object data from a given class. This
+        method has been created to work with the Consumer and Token class."""
+        # Create dummy data from the given class.
         dummy = {'key1': cls('key1', 'secret'),
                  'key2': cls('key2', 'secret'),
                  'key3': cls('key3', 'secret'),
                  }
+        # Assign the dummy data to the given assignable
         assignable.update(dummy)
         return assignable
 
     def _make_request(self, path='/'):
+        """Creates a blank request."""
         request = Request.blank(path)
         return request
 
 
 class StorageTest(ProviderTestBase):
-    """This is more or less a test of the DummyStorage, but this test serves
-    an important role in testing the Storage interface."""
+    """Tests the BaseStorage class."""
 
     def setUp(self):
-        # make a dummy storage
+        # Create a dummy storage
         self.storage = self._make_storage()
 
     def test_consumers(self):
@@ -240,18 +244,21 @@ class ProviderApplicationCallsTest(ProviderTestBase):
     def test_deleteAccessToken(self):
         """Delete the 'key2' access token from the storage using
         the deleteAccessToken call."""
-        # add some details to the request
+        # Add some details to the request
         self._set_params('key2')
 
-        # trigger the call and test the response
+        # Trigger the call and test the response.
         from wsgioauth.calls import deleteAccessToken
         data = self._call_and_extract(deleteAccessToken)
-        self.failUnless(data, "The deleteRequestToken call should have returned True.")
+        self.failUnless(data, "The deleteRequestToken call should have "
+            "returned True.")
         self.failUnless('key2' not in self.storage.access_tokens)
 
-        # trigger the call again except this time without a real consumer key
+        # Trigger the call again, except this time without a real consumer
+        #   key.
         self._set_params('does not exist')
-        self.failUnlessRaises(xmlrpclib.Fault, deleteAccessToken, self.storage, self.request)
+        self.failUnlessRaises(xmlrpclib.Fault, deleteAccessToken,
+            self.storage, self.request)
 
 
 class MockHandler(object):
@@ -269,7 +276,7 @@ class ProviderApplicationTest(ProviderTestBase):
         storage = getattr(self, 'storage', None)
         if storage is None:
             storage = self._make_storage()
-        def storage_factory(config):
+        def storage_factory(environ, config):
             return storage
         app = Application(storage_factory)
         return app
@@ -278,28 +285,29 @@ class ProviderApplicationTest(ProviderTestBase):
         """Test the registration of the various XML-RPC calls (routes)
         in the application. An HTTP 500 is considered a passing test,
         because it means that a route was found, but could not complete."""
-        # make a request factory because we are going to be testing multiple
-        #   paths... this just makes it easier
+        # Create a request factory for use in testing multiple paths.
         def create_request(call_name=''):
-            """Creates a dummy request. This factory is only useful to this test."""
+            """Creates a dummy request. This factory is only useful to this
+            test."""
             req = self._make_request()
             req.content_type = 'text/xml'
             req.body = xmlrpclib.dumps(tuple(), call_name)
             return req
         app = self._make_app()
-        # register the calls
+        # Register the calls with the global variables.
         from wsgioauth.utils import CALLS
         from wsgioauth.mock import ROUTES
         from wsgioauth import calls
         CALLS.update(ROUTES)
-        # the handler is used as a dummy start_response catcher, it also
+        # The handler is used as a dummy start_response catcher, it also
         #   helps grab some of the response that we are testing against
         handler = MockHandler()
 
         for route in ROUTES.keys():
             request = create_request(route)
             response_body = app(request.environ, handler.start_response)
-            self.failIfEqual(handler.status, '404 Not Found', "Failed to route to the %s call." % route)
+            self.failIfEqual(handler.status, '404 Not Found',
+                "Failed to route to the %s call." % route)
 
 
 # SPEC 1.0a appendix A "Documentation and Registration"
@@ -309,57 +317,51 @@ CONSUMER = "http://printer.example.com"
 #   domain, notice the ".net")
 SERVICE_PROVIDER = "https://photos.example.net"
 
-# declared by the Service Provider for use by the Consumer
+# Declared by the Service Provider for use by the Consumer
 CONSUMER_KEY = "dpf43f3p2l4k3l03"
 CONSUMER_SECRET = "kd94hf93k423kf44"
-# defined by the Consumer in the token_request
+# Defined by the Consumer in the token request
 CALLBACK_URL = "http://printer.example.com/request_token_ready"
 
-# defined by the Service Provider
+# Defined by the Service Provider
 AUTHORIZATION = 'authorize'
 AUTHORIZATION_URL = SERVICE_PROVIDER + "/" + AUTHORIZATION
-# defined by the Service Provider
+# Defined by the Service Provider
 REQUEST_TOKEN = 'request_token'
 REQUEST_TOKEN_URL = SERVICE_PROVIDER + "/" + REQUEST_TOKEN
-# defined by the Service Provider
+# Defined by the Service Provider
 ACCESS_TOKEN = 'access_token'
 ACCESS_TOKEN_URL = SERVICE_PROVIDER + "/" + ACCESS_TOKEN
 
-# requested parameters from the Consumer to the Service Provider
+# Requested parameters from the Consumer to the Service Provider
 RESOURCE_PARAMETERS = {'file': 'vacation.jpg', 'size': 'original'}
-# the Protected Resource is defined by the Service Provider
+# The Protected Resource is defined by the Service Provider
 RESOURCE_URL = SERVICE_PROVIDER.replace('https', 'http') + "/photos"
 
-def echo_app(environ, start_response):
-    """Simple app that echos a POST request"""
-    req = Request(environ)
-    resp = Response(urllib.urlencode(req.params))
-    return resp(environ, start_response)
-
 
 class ProviderMiddlewareTestBase(ProviderTestBase):
 
     def _make_middleware(self):
-        # create the storage factory
+        # Create the storage factory
         storage = getattr(self, 'storage', None)
         if storage is None:
             storage = self._make_storage()
         def storage_factory(environ, config):
             return storage
 
-        # make the filter (aka middleware)
-        from wsgioauth.provider import Filter
-        middleware = Filter(echo_app, storage_factory)
+        # Make the filter (aka middleware)
+        from wsgioauth.provider import Middleware
+        from wsgioauth.mock import echo_app
+        middleware = Middleware(echo_app, storage_factory)
         return middleware
 
     def _setup_signatures(self):
-        # setup signing methods
+        # Setup signing methods
         from wsgioauth.signatures import HMAC_SHA1, PLAINTEXT
         self.signature_method_plaintext = PLAINTEXT()
         self.signature_method_hmac_sha1 = HMAC_SHA1()
 
 
-# SPEC 1.0 section "Service Provider Issues an Unauthorized Request Token"
 # SPEC 1.0a section "Service Provider Issues an Unauthorized Request Token"
 class ProviderMiddlewareTest(ProviderMiddlewareTestBase):
 
@@ -367,13 +369,12 @@ class ProviderMiddlewareTest(ProviderMiddlewareTestBase):
         self.storage = self._make_storage()
         self.middleware = self._make_middleware()
         self._setup_signatures()
-        # setup the consumer
+        # Setup the consumer
         self.consumer = self.storage.add_consumer(CONSUMER_KEY, CONSUMER_SECRET)
 
     def tearDown(self):
         del self.storage
         del self.middleware
-        # remove the consumer
         del self.consumer
 
     def _extract_address_and_query(self, url):
@@ -381,9 +382,28 @@ class ProviderMiddlewareTest(ProviderMiddlewareTestBase):
         parts = urlparse.urlparse(url)
         scheme, netloc, path, params, query, fragment = parts[:6]
         address = scheme + '://' + netloc + path
-        query_string = urlparse.parse_qs(query)
+        query_string = dict(urlparse.parse_qsl(query))
         return address, query_string
 
+    def test_non_oauth_request(self):
+        """Check for the proper erros when a non-oauth request is made."""
+        data = dict(one=1, two=2)
+        # Make the request for a request_token
+        from wsgioauth.request import Request
+        req = Request.blank(REQUEST_TOKEN_URL, POST=data)
+        from wsgioauth.provider import NotAnOAuthRequest
+        self.failUnlessRaises(NotAnOAuthRequest, self.middleware.process, self.storage, req)
+
+    def test_partial_oauth_request(self):
+        """Checks to see if the request will raise an error when only some of
+        the OAuth parameters are sent."""
+        data = dict(oauth_nonce='123456789',count='dracula')
+        # Create the request for a request token
+        from wsgioauth.request import Request
+        req = Request.blank(REQUEST_TOKEN_URL, POST=data)
+        from wsgioauth.provider import PartialOAuthRequest
+        self.failUnlessRaises(PartialOAuthRequest, self.middleware.process, self.storage, req)
+
     def test_via_post(self):
         """Test the whole OAuth process using the HTTP POST method.
         1. Request Token
@@ -391,65 +411,88 @@ class ProviderMiddlewareTest(ProviderMiddlewareTestBase):
         3. Access Token
         4. Protected Resource
         
-        It would seem that there is no reason to check the storage for the
-        tokens as they are created because the following step will fail
-        without their presents.
+        There is no reason to check the storage for the token creation,
+        because the later step will fail from the current steps inability to
+        successfully store the token.
         """
         from wsgioauth.provider import Token
         from wsgioauth.request import Request
-        # 
+        # ===================================================================
         # 1. Request Token
-        # 
+        # ===================================================================
 
-        # setup request params for an oauth request_token from the consumer
+        # Setup the request params for an OAuth request token.
+        # This is initialized by the consumer for a user new to the consumer,
+        #   that has a previously expired access token or for a user that has
+        #   previously declined the use of the access token.
         from oauth2 import generate_nonce, generate_timestamp
         data = {'oauth_callback': CALLBACK_URL,
                 'oauth_consumer_key': self.consumer.key,
                 'oauth_nonce': generate_nonce(),
-                'oauth_signature': self.signature_method_plaintext.sign(None, self.consumer, None),
+                'oauth_signature': self.signature_method_plaintext.sign(
+                    None, self.consumer, None),
                 'oauth_signature_method': self.signature_method_plaintext.name,
                 'oauth_timestamp': generate_timestamp(),
                 'oauth_version': '1.0a',
                 }
 
-        # make the request for a request_token
+        # Create the request made by the consuemr for a request token.
         req = Request.blank(REQUEST_TOKEN_URL, POST=data)
-        # analyze the response for the request token
+        # Call the middlware with the consumer request.
         resp = self.middleware.process(self.storage, req)
+        # Capture the request that has been given back to us.
         request_token = Token.from_string(resp.body)
         resp_data = urlparse.parse_qs(resp.body)
-        self.failUnlessEqual(resp_data['oauth_callback_confirmed'][0], 'true')
+        # Check the response for a callback confirmation. This is done so
+        #   that we know where the user will be sent after authorization.
+        self.failUnlessEqual(request_token.callback_confirmed, 'true')
 
-        # 
+        # ===================================================================
         # 2. Authorization
-        # 
-        # the consumer is now ready to redirect the user's browser to the
-        #   service provider's authorization URL
+        # ===================================================================
 
-        # setup request params for an oauth authorization from the consumer
+        # The consumer redirects the user's browser to the service provider's
+        #   authorization URL.  The user will authenticate and allow or
+        #   decline the consumer access to the protected resource.
+        # We do not use authentication in this tests. Instead we use the
+        #   no_auth plugin, which simply redirects the user to the callback
+        #   URL.
+
+        # Setup request params for an OAuth authorization, done by the user.
+        # We send the service provider the OAuth token key so that it can
+        #   identify the user with the token.
         data = {'oauth_token': request_token.key}
 
-        # make the request for authorization
+        # Create the request made by the user as directed by the consumer to
+        #   the authorization URL.
         req = Request.blank(AUTHORIZATION_URL, POST=data)
-        # analyze the response the authorization redirect
+        # Call the middlware with the user request, where the user would
+        #   authenticate with the service provider.  See the notes above
+        #   about the no_auth plugin for information about why we aren't
+        #   sending any credentials.
         resp = self.middleware.process(self.storage, req)
 
-        # check for redirect to the consumer's callback url
+        # Check for redirect to the consumer's callback URL.
         address, query_string = self._extract_address_and_query(resp.headers['location'])
         self.failUnlessEqual(address, CALLBACK_URL)
 
-        # verify the oauth_token is present
-        self.failUnlessEqual(query_string['oauth_token'][0], request_token.key)
-        # TODO: send the oauth_verifier with the response via the dummy authentication proceedure?
-        verifier = None
+        # Verify the OAuth token is present.
+        self.failUnlessEqual(query_string['oauth_token'], request_token.key)
+        verifier = query_string['oauth_verifier']
 
-        # 
+        # ===================================================================
         # 3. Access Token
-        # 
-        # the consumer is now ready to request an access token from the
-        #   service provider's access token URL
+        # ===================================================================
 
-        # setup request params for an oauth access token from the consumer
+        # The consumer can request an access token from the service provider
+        #   after recieving a verifier from the user and/or upon a request to
+        #   the callback URL.
+
+        # Setup request params for an OAuth access token.
+        # The access token is a product of the request token and user
+        #   authorization.  Together these two items are used to obtain an
+        #   access token, which will be used to access the protected
+        #   resource.
         data = {'oauth_token': request_token.key,
                 'oauth_consumer_key': self.consumer.key,
                 'oauth_nonce': generate_nonce(),
@@ -460,59 +503,88 @@ class ProviderMiddlewareTest(ProviderMiddlewareTestBase):
                 'oauth_version': '1.0a',
                 } # -- no verifier in SPEC version 1.0
 
-        # make the request for the access token
+        # Create the request made by the consumer to obtain an access token.
         req = Request.blank(ACCESS_TOKEN_URL, POST=data)
-        # analyze the response for the access_token
+        # Call the middlware with the consumer request.
         resp = self.middleware.process(self.storage, req)
         access_token = Token.from_string(resp.body)
 
-        # 
+        # ===================================================================
         # 4. Protected Resource
-        # 
-        # the consumer is now ready to request an access to the protected
-        #   resource on behave of the user
+        # ===================================================================
 
-        # setup request params for the protected resource
+        # The consumer can access the protected resource on behave of the
+        #   user by providing the access token as part of the request.
+
+        # Setup request params for accessing the protected resource.
         data = {'oauth_token': access_token.key,
                 'oauth_consumer_key': self.consumer.key,
                 'oauth_nonce': generate_nonce(),
-                'oauth_signature_method': self.signature_method_hmac_sha1.name,
+                'oauth_signature_method':
+                    self.signature_method_hmac_sha1.name,
                 'oauth_timestamp': generate_timestamp(),
                 'oauth_version': '1.0a',
                 }
+        # Attach the resource specific parameters.
         data.update(RESOURCE_PARAMETERS)
 
-        # make the request for the access token
+        # Create the request made by the consumer for the protected resource.
         req = Request.blank(RESOURCE_URL, POST=data)
-        oauth_signature = self.signature_method_hmac_sha1.sign(req, self.consumer, access_token)
+        # Sign the request using the HMAC SHA1 signature method.
+        oauth_signature = self.signature_method_hmac_sha1.sign(req,
+            self.consumer, access_token)
+        # Update the parameters and recreate the request.
         data.update(dict(oauth_signature=oauth_signature))
+        # The request needs to be created again because webob requests have
+        #   read-only parameters, unless one wishes to override the
+        #   wsgi.input environment key with new post data. It is far easier
+        #   to recreate the request.
+        # We create the request and sign it because the signature method
+        #   builds a base signature from the request method, url and
+        #   posted parameters without the oauth signature parameters itself.
         req = Request.blank(RESOURCE_URL, POST=data)
 
-        # analyze the response the authorization redirect
+        # Create a mock request handler because we need to go through the
+        #   middleware to the application and back. To do this we need
+        #   something that will look like a valid start_response function.
+        # Note that the middleware is being called directly, rather than
+        #   using the process method as seen in the previvious steps. This is
+        #   because we need to touch the application, which the process
+        #   method does not do, but the middleware's __call__ does.
         handler = MockHandler()
+        # Call the middleware
         body = self.middleware(req.environ, handler.start_response)
+        # Grab the response data and parse it.  We are using an echo
+        #   application to verify the request has successfully passed
+        #   through the middleware.
         resp_data = body[0]
-        self.failUnlessEqual(resp_data, urllib.urlencode(RESOURCE_PARAMETERS))
+        encoded_params = urllib.urlencode(RESOURCE_PARAMETERS)
+        # Verify the response matches what we sent to the echo application.
+        self.failUnlessEqual(resp_data, encoded_params)
 
     def test_nonce(self):
-        # setup request params for an oauth request_token from the consumer
+        # Setup request params for an OAuth request token
         from oauth2 import generate_timestamp
         data = {'oauth_callback': CALLBACK_URL,
                 'oauth_consumer_key': self.consumer.key,
                 'oauth_nonce': '1234567890',
-                'oauth_signature': self.signature_method_plaintext.sign(None, self.consumer, None),
+                'oauth_signature': self.signature_method_plaintext.sign(None,
+                    self.consumer, None),
                 'oauth_signature_method': self.signature_method_plaintext.name,
                 'oauth_timestamp': generate_timestamp(),
                 'oauth_version': '1.0a',
                 }
 
-        # make the request for a request_token
+        # Create the request
         from wsgioauth.request import Request
         req = Request.blank(REQUEST_TOKEN_URL, POST=data)
-        # analyze the response for the request token
+        # Call the middleware and grab the response, which should be valid.
         resp = self.middleware.process(self.storage, req)
+        # Make the same request again, which should raise a NOnceReplayed
+        #   error as a result of using the same nonce value twice.
         from wsgioauth.provider import NOnceReplayed
-        self.failUnlessRaises(NOnceReplayed, self.middleware.process, self.storage, req)
+        self.failUnlessRaises(NOnceReplayed, self.middleware.process,
+            self.storage, req)
 
 
 if __name__ == '__main__':
