@@ -8,7 +8,7 @@ class HMAC_SHA1(SignatureMethod_HMAC_SHA1):
     def signing_base(self, request, consumer, token):
         sig = (
             escape(request.method),
-            escape(request.url),
+            escape(request.path_url),
             escape(get_normalized_parameters(request)),
         )
 
